package com.socialmine.mergedservices;


import java.text.SimpleDateFormat;

import android.app.Service;
import android.content.Intent;
import android.database.Cursor;
import android.os.IBinder;
import android.os.Looper;
import android.provider.ContactsContract.Contacts;
import android.provider.ContactsContract.Data;
import android.provider.ContactsContract.RawContacts;
import android.provider.ContactsContract.CommonDataKinds.Email;
import android.provider.ContactsContract.CommonDataKinds.Organization;
import android.provider.ContactsContract.CommonDataKinds.Phone;
import android.provider.ContactsContract.CommonDataKinds.StructuredPostal;
import android.provider.ContactsContract.CommonDataKinds.Website;
import android.util.Log;


public class ContactsService extends Service	{

	
	//// Variable Declaration ////
	
	private static final String TAG = ContactsService.class.getSimpleName();
	public MyContactsUpdater updater;
	public MyContactsCollector Collector;
	public DBContactsService contactsDB;
	public boolean isRunning = false;



	@Override
	public IBinder onBind(Intent intent) {
		return null;
	}
	
	@Override
	public void onCreate() {
		super.onCreate();
		
		contactsDB = new DBContactsService(getApplicationContext());
		updater = new MyContactsUpdater();		

		Log.d(TAG, "Created ContactsService");
	}

	@Override
	public synchronized void onStart(Intent intent, int startId) {
		super.onStart(intent, startId);

		// Starting the Service is only possible if it's not already running

		if (!this.isRunning)	{
			updater.start();
			this.isRunning = true;
			Log.d(TAG, "Started ContactsService");
		}
				


	}

	@Override
	public synchronized void onDestroy() {
		super.onDestroy();

		if (this.isRunning)	{
			updater.interrupt();
			this.isRunning = false;
			Log.d(TAG, "Destroyed ContactsService");
			updater = null;			// for garbage collection
		}




	}


	//////// Private-Updater Thread /////////

	
	class MyContactsUpdater extends Thread	{

		static final long DELAY = 1000 * 60 * 60 * 24;		// 1d periodic updates
		private boolean isRunning = true;




		@Override
		public void run() {

			boolean status = true;
			while (isRunning) {
				try {
					Log.d(TAG, "-- Updater running --");
					
					// Start Collection
					Collector = new MyContactsCollector();

					
					if(status)
					{
						Looper.prepare();
						status=false;
					}

					
					// Sleep
					Log.d(TAG, "-- Updater Sleeping --");
					Thread.currentThread();
					Thread.sleep(DELAY);

				} catch (InterruptedException e) {
					// Interrupted
					isRunning = false;
				}
			}	// endless while-loop
		}



	}


	
	public boolean isRunning()	{
		return this.isRunning;
	}



	/* Collection-Class: Collects Data & stores it into database */
	
	public class MyContactsCollector	{

			
		////////////////////// Constructor: Query list of all available contacts ////////////////

		
		public MyContactsCollector()	{

			Log.d(TAG, "Collector activated");
		
			final String[] projection = new String[] {
					RawContacts.CONTACT_ID,	// the contact id column
			};
	
			final Cursor rawContacts = getContentResolver().query(
					RawContacts.CONTENT_URI,	// the URI for raw contact provider
					projection,					
					null,						// selection = null, retrieve all entries
					null,						// selection is without parameters
					null);						// do not order
	
			final int contactIdColumnIndex = rawContacts.getColumnIndex(RawContacts.CONTACT_ID);

			int i = 1;
			if(rawContacts.moveToFirst()) {
			
				contactsDB.open();

				while(!rawContacts.isAfterLast()) {		// still a valid entry left?
				
					final int contactId = rawContacts.getInt(contactIdColumnIndex);										
					String k = "" + contactId;
					Log.d(TAG, "Entry: " + i);
					Log.d(TAG, "ContactID: " + k);
				
					queryContactName(contactId);		// get name of contact
					queryAllPhoneNumbers(contactId);	// get all numbers of contact
					queryAllEmailAddresses(contactId);	// get all email addresses of contact
					queryAllPostalAddresses(contactId);	// get all postal addresses of contact
					queryOrganization(contactId);		// get work-organization of contact
					queryWebsites(contactId);			// get web sites of contact

				
					rawContacts.moveToNext();			// move to the next entry
					i++;
				}
			
				contactsDB.close();
			}
		
			rawContacts.close();
		
		}
	
		
	/////// Method which finds name of contact matching contactId ///////

		
	private String queryContactName(int contactId) {
		
		String n = null;
		
		final String[] projection = new String[] {
				Contacts.DISPLAY_NAME,					// the name of the contact
		};
		
		final Cursor contact = getContentResolver().query(
				Contacts.CONTENT_URI,
				projection,
				Contacts._ID + "=?",						// filter entries on the basis of the contact id
				new String[]{String.valueOf(contactId)},	// the parameter to which the contact id column is compared to
				null);
					
		if(contact.moveToFirst()) {
			n = contact.getString(contact.getColumnIndex(Contacts.DISPLAY_NAME));
			Log.d(TAG, "Name: " + n);
			
			final String c = contactId + "";
			contactsDB.insertName(c, n);

		}
		
		contact.close();		

		return n;
	}
	
	
	/////// Method which finds all types of phonenumbers of the contact matching contactId ///////

	
	public void queryAllPhoneNumbers(int contactId) {
		final String[] projection = new String[] {
				Phone.NUMBER,
				Phone.TYPE,
		};

		final Cursor phone = getContentResolver().query(
				Phone.CONTENT_URI,	
				projection,
				Data.CONTACT_ID + "=?",
				new String[]{String.valueOf(contactId)},
				null);

		if(phone.moveToFirst()) {
			final int contactNumberColumnIndex = phone.getColumnIndex(Phone.NUMBER);
			final int contactTypeColumnIndex = phone.getColumnIndex(Phone.TYPE);
			
			while(!phone.isAfterLast()) {
				final String number = phone.getString(contactNumberColumnIndex);
				final int test = phone.getInt(contactTypeColumnIndex);
				final String type = phoneType(test);
				Log.d(TAG, "Phonenumber: " + number + " for type: " + type);
				
				final String c = contactId + "";
				contactsDB.insertPhone(c, number, type);

				
				phone.moveToNext();
			}
			
		}
		phone.close();
	}
	
	
	/////// Method which finds all types of postal-addresses of the contact matching contactId ///////
	
	public void queryAllPostalAddresses(int contactId) {
		final String[] projection = new String[] {
				StructuredPostal.FORMATTED_ADDRESS,						
				StructuredPostal.TYPE
		};

		final Cursor address = getContentResolver().query(
				StructuredPostal.CONTENT_URI,	
				projection,
				Data.CONTACT_ID + "=?",
				new String[]{String.valueOf(contactId)},
				null);

		if(address.moveToFirst()) {
			final int contactAddressColumnIndex = address.getColumnIndex(StructuredPostal.FORMATTED_ADDRESS);
			final int contactTypeColumnIndex = address.getColumnIndex(StructuredPostal.TYPE);
			
			while(!address.isAfterLast()) {
				final String postal = address.getString(contactAddressColumnIndex);
				final String test = address.getString(contactTypeColumnIndex);
				final String type = addressType(test);
				Log.d(TAG, "Postal Address: " + postal + " for type: " + type);
				
				final String c = contactId + "";
				contactsDB.insertAddress(c, postal, type);
				
				
				address.moveToNext();
			}
			
		}
		address.close();
	}
	
	
	/////// Method which finds all types of email-addresses of the contact matching contactId ///////

	
	public void queryAllEmailAddresses(int contactId) {
		final String[] projection = new String[] {
				Email.DATA,							// use Email.ADDRESS for API-Level 11+
				Email.TYPE
		};

		final Cursor email = getContentResolver().query(
				Email.CONTENT_URI,	
				projection,
				Data.CONTACT_ID + "=?",
				new String[]{String.valueOf(contactId)},
				null);

		if(email.moveToFirst()) {
			final int contactEmailColumnIndex = email.getColumnIndex(Email.DATA);
			final int contactTypeColumnIndex = email.getColumnIndex(Email.TYPE);
			
			while(!email.isAfterLast()) {
				final String address = email.getString(contactEmailColumnIndex);
				final String test = email.getString(contactTypeColumnIndex);
				final String type = addressType(test);
				Log.d(TAG, "Email: " + address + " for type: " + type);
				
				final String c = contactId + "";
				contactsDB.insertEmail(c, address, type);
				
				email.moveToNext();
			}
			
		}
		email.close();
	}
	
	
	/////// Method which finds the organization of the contact matching contactId ///////
	
	
	public void queryOrganization(int contactId) {
		final String[] projection = new String[] {
				Organization.COMPANY,
				Organization.TITLE
		};
		
		String where = Data.CONTACT_ID + " = ? AND " + Data.MIMETYPE + " = ?"; 
		
		String[] whereParameters = new String[]{
				String.valueOf(contactId),
				Organization.CONTENT_ITEM_TYPE
		};

		final Cursor organization = getContentResolver().query(
				Data.CONTENT_URI,	
				projection,
				where,
				whereParameters,
				null);

		if(organization.moveToFirst()) {
			final int contactCompanyColumnIndex = organization.getColumnIndex(Organization.COMPANY);
			final int contactTitleColumnIndex = organization.getColumnIndex(Organization.TITLE);
			
			while(!organization.isAfterLast()) {
				final String company = organization.getString(contactCompanyColumnIndex);
				final String title = organization.getString(contactTitleColumnIndex);

				Log.d(TAG, "Company: " + company + " with title: " + title);
				
				final String c = contactId + "";
				contactsDB.insertPhone(c, company, title);
				
				organization.moveToNext();
			}
			
		}
		organization.close();
	}
		
	
	
	/////// Method which finds the websites of the contact matching contactId ///////

	
	public void queryWebsites(int contactId) {
		
		final String[] projection = new String[] {
				Website.URL
		};
		
		String where = Data.CONTACT_ID + " = ? AND " + Data.MIMETYPE + " = ?"; 
		
		String[] whereParameters = new String[]{
				String.valueOf(contactId),
				Website.CONTENT_ITEM_TYPE
		};

		final Cursor website = getContentResolver().query(
				Data.CONTENT_URI,	
				projection,
				where,
				whereParameters,
				null);

		if(website.moveToFirst()) {
			final int contactWebsiteColumnIndex = website.getColumnIndex(Website.URL);
			
			while(!website.isAfterLast()) {
				final String url = website.getString(contactWebsiteColumnIndex);

				Log.d(TAG, "Website: " + url);
									
				website.moveToNext();
			}
			
		}
		website.close();
	}
	
	
	
	///////////////// Formatting of variables //////////////////////

	
	/* Specify formatting of data and time */
	SimpleDateFormat formatDate = new SimpleDateFormat("dd-MM-yyyy");
	SimpleDateFormat formatTime = new SimpleDateFormat("HH:mm:ss");

    /* Specify interpretation of Phone-Type */
    public String phoneType(int t)    {
    	
		String g = null;

		switch(t)	{
			case Phone.TYPE_MOBILE: 
				g = "Mobile";
				break;
			case Phone.TYPE_HOME: 
				g = "Home";
				break;
			case Phone.TYPE_WORK: 
				g = "Work";
				break;
			default:
				g = "Other";
				break;
		}
		return g; 
		
    }
    
    /* Specify interpretation of Email & Postal-address - Type */
    public String addressType(String g)    {
        
		if ("1".equals(g))			return "Home";
		else if ("2".equals(g))		return "Work";
		else						return "Other";
        
    }
	
	
	
} /* End of Class MyContactsCollector */


}
