package com.socialmine.mergedservices;




import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class DBContactsService {

	   public static final String KEY_ROWID = "_id";

       //public static final String KEY_DATE = "Date";
       //public static final String KEY_TIME = "Time";
       public static final String KEY_CONTACTID = "ContactID";
	   public static final String KEY_NAME = "Name";
       public static final String KEY_PHONE = "Phonenumber";
       public static final String KEY_PHONETYPE = "Phonetype";
       public static final String KEY_EMAIL = "Emailaddress";
       public static final String KEY_EMAILTYPE = "Emailtype";
       public static final String KEY_ADDRESS = "Address";
       public static final String KEY_ADDRESSTYPE = "Addresstype";
       public static final String KEY_WEBSITE = "WebsiteURL";
       public static final String KEY_COMPANY = "CompanyName";
       public static final String KEY_TITLE = "Occupationtitle";
       private static final String TAG = "DBContacts";
       
       private static final String DATABASE_NAME = "userdata";
       private static final String DATABASE_TABLENAME = "ContactName";
       private static final String DATABASE_TABLEPHONE = "ContactPhoneDetails";
       private static final String DATABASE_TABLEEMAIL = "ContactEmailDetails";
       private static final String DATABASE_TABLEADDRESS = "ContactAddressDetails";
       private static final String DATABASE_TABLEWEBSITE = "ContactWebsites";
       private static final String DATABASE_TABLEORGANIZATION = "ContactOrganizationDetails";

       private static final int DATABASE_VERSION = 2;

       private static final String DATABASE_CREATE_TABLENAME =
    	   "create table "+DATABASE_TABLENAME+" (_id integer primary key autoincrement, "
           + "ContactID text not null, Name text not null);";
       private static final String DATABASE_CREATE_TABLEPHONE =
    	   "create table "+DATABASE_TABLEPHONE+" (_id integer primary key autoincrement, "
           + "ContactID text not null, Phonenumber text not null, Phonetype text not null);";       
       private static final String DATABASE_CREATE_TABLEEMAIL =
    	   "create table "+DATABASE_TABLEEMAIL+" (_id integer primary key autoincrement, "
           + "ContactID text not null, Emailaddress text not null, Emailtype text not null);";
       private static final String DATABASE_CREATE_TABLEADDRESS =
        	"create table "+DATABASE_TABLEADDRESS+" (_id integer primary key autoincrement, "
            + "ContactID text not null, Address text not null, Addresstype text not null);";
       private static final String DATABASE_CREATE_TABLEWEBSITE =
            "create table "+DATABASE_TABLEWEBSITE+" (_id integer primary key autoincrement, "
            + "ContactID text not null, WebsiteURL text not null);";
       private static final String DATABASE_CREATE_TABLEORGANIZATION =
            "create table "+DATABASE_TABLEORGANIZATION+" (_id integer primary key autoincrement, "
            + "ContactID text not null, CompanyName text not null, Occupationtitle text not null);";       
           
           
           
       private final Context context;  

       private DatabaseHelper DBHelper;
       private SQLiteDatabase db;

       public DBContactsService(Context ctx) 
       {
           this.context = ctx;
           DBHelper = new DatabaseHelper(context);
       }
           
       private static class DatabaseHelper extends SQLiteOpenHelper 
       {
           DatabaseHelper(Context context) 
           {
               super(context, DATABASE_NAME, null, DATABASE_VERSION);
        	   Log.d(TAG, "Creating Database...");

           }

           @Override
           public void onCreate(SQLiteDatabase db) 
           {
        	   
               db.execSQL(DATABASE_CREATE_TABLENAME);
               db.execSQL(DATABASE_CREATE_TABLEPHONE);
               db.execSQL(DATABASE_CREATE_TABLEEMAIL);
               db.execSQL(DATABASE_CREATE_TABLEADDRESS);
               db.execSQL(DATABASE_CREATE_TABLEWEBSITE);
               db.execSQL(DATABASE_CREATE_TABLEORGANIZATION);
               Log.d(TAG, "Created Tables");
           }

           @Override
           public void onUpgrade(SQLiteDatabase db, int oldVersion, 
                                 int newVersion) 
           {
               Log.w(TAG, "Upgrading database from version " + oldVersion 
                     + " to "
                     + newVersion + ", which will destroy all old data");
               db.execSQL("DROP TABLE IF EXISTS titles");
               onCreate(db);
           }
       }    

       //---opens the database---
       public DBContactsService open() throws SQLException 
       {
           db = DBHelper.getWritableDatabase();
           return this;
       }

       //---closes the database---    
       public void close() 
       {
           DBHelper.close();
       }
       
       //---insert new contact logs into the database---
       
       public long insertName(String contactID, String name) 
       {
           ContentValues initialValues = new ContentValues();
           initialValues.put(KEY_CONTACTID, contactID);
           initialValues.put(KEY_NAME, name);     
           
           return db.insert(DATABASE_TABLENAME, null, initialValues);
       }      

       public long insertPhone(String contactID, String phonenumber, String phonetype) 
       {
           ContentValues initialValues = new ContentValues();
           initialValues.put(KEY_CONTACTID, contactID);
           initialValues.put(KEY_PHONE, phonenumber);     
           initialValues.put(KEY_PHONETYPE, phonenumber);     
           
           return db.insert(DATABASE_TABLEPHONE, null, initialValues);
       }
       
       public long insertEmail(String contactID, String email, String type) 
       {
           ContentValues initialValues = new ContentValues();
           initialValues.put(KEY_CONTACTID, contactID);
           initialValues.put(KEY_EMAIL, email);     
           initialValues.put(KEY_EMAILTYPE, type);     
           
           return db.insert(DATABASE_TABLEEMAIL, null, initialValues);
       }

       public long insertAddress(String contactID, String address, String type) 
       {
           ContentValues initialValues = new ContentValues();
           initialValues.put(KEY_CONTACTID, contactID);
           initialValues.put(KEY_ADDRESS, address);     
           initialValues.put(KEY_ADDRESSTYPE, type);     
           
           return db.insert(DATABASE_TABLEADDRESS, null, initialValues);
       } 

       public long insertWebsite(String contactID, String url) 
       {
           ContentValues initialValues = new ContentValues();
           initialValues.put(KEY_CONTACTID, contactID);
           initialValues.put(KEY_WEBSITE, url);     
           
           return db.insert(DATABASE_TABLEWEBSITE, null, initialValues);
       }
       
       public long insertOrganization(String contactID, String company, String title) 
       {
           ContentValues initialValues = new ContentValues();
           initialValues.put(KEY_CONTACTID, contactID);
           initialValues.put(KEY_COMPANY, company);     
           initialValues.put(KEY_TITLE, title);     
           
           return db.insert(DATABASE_TABLEORGANIZATION, null, initialValues);
       }
       
       //---retrieves all the LOGS---
      /*public Cursor getAllCallLogs() 
       {
           return db.query(DATABASE_TABLE, new String[] {
                 KEY_ROWID,
                 KEY_DATE,
                 KEY_TIME,
                 KEY_NAME,
                   }, 
                   null, 
                   null, 
                   null, 
                   null, 
                   null,
                   null);
       }*/
       
       //---retrieves all the LOGS---
       /*public Cursor getAllCallLogs() 
        {
            return db.query(DATABASE_TABLE, new String[] {
                  KEY_ROWID,
                  KEY_DATE,
                  KEY_TIME,
                  KEY_NAME,
                    }, 
                    null, 
                    null, 
                    null, 
                    null, 
                    null,
                    null);
        }*/
       
       public Cursor getName() 
        {
            return db.query(DATABASE_TABLENAME, new String[] {
                  KEY_ROWID,
                  KEY_CONTACTID,
                  KEY_NAME,
                    }, 
                    null, 
                    null, 
                    null, 
                    null, 
                    null,
                    null);
        }      

       public Cursor getPhone() 
       {
           return db.query(DATABASE_TABLEPHONE, new String[] {
                 KEY_ROWID,
                 KEY_CONTACTID,
                 KEY_PHONE,
                 KEY_PHONETYPE,
                   }, 
                   null, 
                   null, 
                   null, 
                   null, 
                   null,
                   null);
       } 

       public Cursor getEmail() 
       {
           return db.query(DATABASE_TABLEEMAIL, new String[] {
                 KEY_ROWID,
                 KEY_CONTACTID,
                 KEY_EMAIL,
                 KEY_EMAILTYPE,
                   }, 
                   null, 
                   null, 
                   null, 
                   null, 
                   null,
                   null);
       } 

       public Cursor getAddress() 
       {
           return db.query(DATABASE_TABLEADDRESS, new String[] {
                 KEY_ROWID,
                 KEY_CONTACTID,
                 KEY_ADDRESS,
                 KEY_ADDRESSTYPE,
                   }, 
                   null, 
                   null, 
                   null, 
                   null, 
                   null,
                   null);
       }

       public Cursor getWebsite() 
       {
           return db.query(DATABASE_TABLEWEBSITE, new String[] {
                 KEY_ROWID,
                 KEY_CONTACTID,
                 KEY_WEBSITE,
                   }, 
                   null, 
                   null, 
                   null, 
                   null, 
                   null,
                   null);
       }  

       public Cursor getOrganization() 
       {
           return db.query(DATABASE_TABLEORGANIZATION, new String[] {
                 KEY_ROWID,
                 KEY_CONTACTID,
                 KEY_COMPANY,
                 KEY_TITLE,
                   }, 
                   null, 
                   null, 
                   null, 
                   null, 
                   null,
                   null);
       }       
       
}