package com.socialmine.mergedservices;



import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.os.IBinder;
import android.os.Looper;
import android.text.format.Time;
import android.util.Log;
import android.widget.Toast;

public class GeolocationService extends Service{

	private GPSUpdater updater;
	private static final String TAG = GeolocationService.class.getSimpleName(); // Define this class as variable for logging
	public boolean isRunning = false;
	public LocationManager mlocManager;
	public MyLocationListener mlocListener;
	public DBGeolocationService db;


	@Override
	public IBinder onBind(Intent intent) {
		return null;
	}
	@Override
	public void onCreate() {
		super.onCreate();

		updater = new GPSUpdater();
		mlocManager = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
		mlocListener = new MyLocationListener();
		db = new DBGeolocationService(getApplicationContext());

		Log.d(TAG, "onCreate'd");
	}

	@Override
	public synchronized void onStart(Intent intent, int startId) {
		super.onStart(intent, startId);

		// Starting the Service is only possible if it's not already running

		if (!this.isRunning)	{
			updater.start();
			this.isRunning = true;
			Log.d(TAG, "onStart'd");
		}
				


	}

	@Override
	public synchronized void onDestroy() {
		super.onDestroy();

		// Stopping Service is only possible if it's not already stopped


		if (this.isRunning)	{
			updater.interrupt();
			this.isRunning = true;
			Log.d(TAG, "onDestroy'd");
		}

		updater = null;			// for garbage collection



	}


	//////// Private-Updater Thread /////////

	class GPSUpdater extends Thread	{

		static final long DELAY = 1000 * 60 * 60 * 2;		// 2h periodic updates
		private boolean isRunning = true;




		@Override
		public void run() {

			boolean status = true;
			while (isRunning) {
				try {
					Log.d(TAG, "-- GPS-Updater running --");

					mlocManager = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
					mlocListener = new MyLocationListener();
					ConnectivityManager cm = (ConnectivityManager) getApplicationContext().getSystemService(CONNECTIVITY_SERVICE);
					NetworkInfo ninf = cm.getActiveNetworkInfo();

					
					if(status)
					{
						Looper.prepare();
						status=false;
					}
					
					if(ninf!=null&&ninf.isConnectedOrConnecting())
						mlocManager.requestLocationUpdates( LocationManager.NETWORK_PROVIDER, 0, 0, mlocListener,Looper.getMainLooper());
					else		
						mlocManager.requestLocationUpdates( LocationManager.GPS_PROVIDER, 0, 0, mlocListener);

//					Looper.loop();

					
					
					// Sleep
					Thread.currentThread();
					Thread.sleep(DELAY);

				} catch (InterruptedException e) {
					// Interrupted
					isRunning = false;
				}
			}	// endless while-loop
		}



	}


	
	public boolean isRunning()	{
		return this.isRunning;
	}



	/* Class My Location Listener */

	class MyLocationListener implements LocationListener

	{

		@Override
		public void onLocationChanged(Location loc)

		{

			loc.getLatitude();

			loc.getLongitude();

			Time t = new Time();
			t.setToNow();
			String time = t.hour +":" + t.minute + ":" + t.second;
			String text = "Time: " + t.hour +":" + t.minute + ":" + t.second+"  Loc-" +
						  "--- Latitude = " + loc.getLatitude() +
						  " Longitude = " + loc.getLongitude() + "\n";


			db.open();
			db.insertLocation(loc.getLatitude(), loc.getLongitude(), time);
			db.close();

			Log.d(TAG, text);
			Log.d(TAG, "-- GPS-Updater going to sleep --");

			mlocManager.removeUpdates(this);
			
		}


		@Override
		public void onProviderDisabled(String provider)

		{

			Toast.makeText( getApplicationContext(),

					"Gps Disabled",

					Toast.LENGTH_SHORT ).show();

		}


		@Override
		public void onProviderEnabled(String provider)

		{

			Toast.makeText( getApplicationContext(),

					"Gps Enabled",

					Toast.LENGTH_SHORT).show();

		}


		@Override
		public void onStatusChanged(String provider, int status, Bundle extras)
		{


		}




	}/* End of Class MyLocationListener */


}
